package com.rnfs;

import android.content.res.AssetFileDescriptor;
import android.content.res.AssetManager;
import android.database.Cursor;
import android.net.Uri;
import android.os.Build;
import android.os.Environment;
import android.os.StatFs;
import android.support.annotation.Nullable;
import android.util.Base64;
import android.util.SparseArray;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.modules.core.RCTNativeAppEventEmitter;
import com.rnfs.DownloadParams;
import com.rnfs.UploadParams;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.net.URL;
import java.security.MessageDigest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

public class RNFSManager extends ReactContextBaseJavaModule {
    private static final String RNFSCachesDirectoryPath = "RNFSCachesDirectoryPath";
    private static final String RNFSDocumentDirectory = "RNFSDocumentDirectory";
    private static final String RNFSDocumentDirectoryPath = "RNFSDocumentDirectoryPath";
    private static final String RNFSExternalCachesDirectoryPath = "RNFSExternalCachesDirectoryPath";
    private static final String RNFSExternalDirectoryPath = "RNFSExternalDirectoryPath";
    private static final String RNFSExternalStorageDirectoryPath = "RNFSExternalStorageDirectoryPath";
    private static final String RNFSFileTypeDirectory = "RNFSFileTypeDirectory";
    private static final String RNFSFileTypeRegular = "RNFSFileTypeRegular";
    private static final String RNFSPicturesDirectoryPath = "RNFSPicturesDirectoryPath";
    private static final String RNFSTemporaryDirectoryPath = "RNFSTemporaryDirectoryPath";
    private SparseArray<Downloader> downloaders = new SparseArray<>();
    private ReactApplicationContext reactContext;
    private SparseArray<Uploader> uploaders = new SparseArray<>();

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "RNFSManager";
    }

    @ReactMethod
    public void pathForBundle(String str, Promise promise) {
    }

    @ReactMethod
    public void pathForGroup(String str, Promise promise) {
    }

    public RNFSManager(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        this.reactContext = reactApplicationContext;
    }

    private Uri getFileUri(String str) throws IORejectionException {
        Uri parse = Uri.parse(str);
        if (parse.getScheme() != null) {
            return parse;
        }
        if (!new File(str).isDirectory()) {
            return Uri.parse("file://" + str);
        }
        throw new IORejectionException("EISDIR", "EISDIR: illegal operation on a directory, read '" + str + "'");
    }

    private String getOriginalFilepath(String str) throws IORejectionException {
        Uri fileUri = getFileUri(str);
        if (!fileUri.getScheme().equals("content")) {
            return str;
        }
        try {
            Cursor query = this.reactContext.getContentResolver().query(fileUri, null, null, null, null);
            return query.moveToFirst() ? query.getString(query.getColumnIndexOrThrow("_data")) : str;
        } catch (IllegalArgumentException unused) {
            return str;
        }
    }

    private InputStream getInputStream(String str) throws IORejectionException {
        try {
            InputStream openInputStream = this.reactContext.getContentResolver().openInputStream(getFileUri(str));
            if (openInputStream != null) {
                return openInputStream;
            }
            throw new IORejectionException("ENOENT", "ENOENT: could not open an input stream for '" + str + "'");
        } catch (FileNotFoundException unused) {
            throw new IORejectionException("ENOENT", "ENOENT: no such file or directory, open '" + str + "'");
        }
    }

    private OutputStream getOutputStream(String str, boolean z) throws IORejectionException {
        try {
            OutputStream openOutputStream = this.reactContext.getContentResolver().openOutputStream(getFileUri(str), z ? "wa" : "w");
            if (openOutputStream != null) {
                return openOutputStream;
            }
            throw new IORejectionException("ENOENT", "ENOENT: could not open an output stream for '" + str + "'");
        } catch (FileNotFoundException unused) {
            throw new IORejectionException("ENOENT", "ENOENT: no such file or directory, open '" + str + "'");
        }
    }

    private static byte[] getInputStreamBytes(InputStream inputStream) throws IOException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byte[] bArr = new byte[1024];
        while (true) {
            try {
                int read = inputStream.read(bArr);
                if (read == -1) {
                    break;
                }
                byteArrayOutputStream.write(bArr, 0, read);
            } finally {
                try {
                    byteArrayOutputStream.close();
                } catch (IOException unused) {
                }
            }
        }
        return byteArrayOutputStream.toByteArray();
    }

    @ReactMethod
    public void writeFile(String str, String str2, ReadableMap readableMap, Promise promise) {
        try {
            byte[] decode = Base64.decode(str2, 0);
            OutputStream outputStream = getOutputStream(str, false);
            outputStream.write(decode);
            outputStream.close();
            promise.a((Object) null);
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void appendFile(String str, String str2, Promise promise) {
        try {
            byte[] decode = Base64.decode(str2, 0);
            OutputStream outputStream = getOutputStream(str, true);
            outputStream.write(decode);
            outputStream.close();
            promise.a((Object) null);
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void write(String str, String str2, int i, Promise promise) {
        try {
            byte[] decode = Base64.decode(str2, 0);
            if (i < 0) {
                OutputStream outputStream = getOutputStream(str, true);
                outputStream.write(decode);
                outputStream.close();
            } else {
                RandomAccessFile randomAccessFile = new RandomAccessFile(str, "rw");
                randomAccessFile.seek((long) i);
                randomAccessFile.write(decode);
                randomAccessFile.close();
            }
            promise.a((Object) null);
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void exists(String str, Promise promise) {
        try {
            promise.a(Boolean.valueOf(new File(str).exists()));
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void readFile(String str, Promise promise) {
        try {
            promise.a((Object) Base64.encodeToString(getInputStreamBytes(getInputStream(str)), 2));
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void read(String str, int i, int i2, Promise promise) {
        try {
            InputStream inputStream = getInputStream(str);
            byte[] bArr = new byte[i];
            inputStream.skip((long) i2);
            promise.a((Object) Base64.encodeToString(bArr, 0, inputStream.read(bArr, 0, i), 2));
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:25:0x004d A[SYNTHETIC, Splitter:B:25:0x004d] */
    /* JADX WARNING: Removed duplicated region for block: B:34:? A[RETURN, SYNTHETIC] */
    @ReactMethod
    public void readFileAssets(String str, Promise promise) {
        Throwable th;
        InputStream inputStream;
        Exception e;
        try {
            inputStream = getReactApplicationContext().getAssets().open(str, 0);
            if (inputStream == null) {
                try {
                    reject(promise, str, new Exception("Failed to open file"));
                    if (inputStream != null) {
                        try {
                            inputStream.close();
                        } catch (IOException unused) {
                        }
                    }
                } catch (Exception e2) {
                    e = e2;
                    try {
                        e.printStackTrace();
                        reject(promise, str, e);
                        if (inputStream == null) {
                            return;
                        }
                        try {
                            inputStream.close();
                        } catch (IOException unused2) {
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        if (inputStream != null) {
                        }
                        throw th;
                    }
                }
            } else {
                byte[] bArr = new byte[inputStream.available()];
                inputStream.read(bArr);
                promise.a((Object) Base64.encodeToString(bArr, 2));
                if (inputStream == null) {
                    return;
                }
                inputStream.close();
            }
        } catch (Exception e3) {
            inputStream = null;
            e = e3;
            e.printStackTrace();
            reject(promise, str, e);
            if (inputStream == null) {
            }
            inputStream.close();
        } catch (Throwable th3) {
            th = th3;
            inputStream = null;
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException unused3) {
                }
            }
            throw th;
        }
    }

    @ReactMethod
    public void hash(String str, String str2, Promise promise) {
        try {
            HashMap hashMap = new HashMap();
            hashMap.put("md5", "MD5");
            hashMap.put("sha1", "SHA-1");
            hashMap.put("sha224", "SHA-224");
            hashMap.put("sha256", "SHA-256");
            hashMap.put("sha384", "SHA-384");
            hashMap.put("sha512", "SHA-512");
            if (hashMap.containsKey(str2)) {
                File file = new File(str);
                if (file.isDirectory()) {
                    rejectFileIsDirectory(promise);
                } else if (!file.exists()) {
                    rejectFileNotFound(promise, str);
                } else {
                    MessageDigest instance = MessageDigest.getInstance((String) hashMap.get(str2));
                    FileInputStream fileInputStream = new FileInputStream(str);
                    byte[] bArr = new byte[10240];
                    while (true) {
                        int read = fileInputStream.read(bArr);
                        if (read == -1) {
                            break;
                        }
                        instance.update(bArr, 0, read);
                    }
                    StringBuilder sb = new StringBuilder();
                    byte[] digest = instance.digest();
                    int length = digest.length;
                    for (int i = 0; i < length; i++) {
                        sb.append(String.format("%02x", Byte.valueOf(digest[i])));
                    }
                    promise.a((Object) sb.toString());
                }
            } else {
                throw new Exception("Invalid hash algorithm");
            }
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void moveFile(String str, String str2, ReadableMap readableMap, Promise promise) {
        try {
            File file = new File(str);
            if (!file.renameTo(new File(str2))) {
                copyFile(str, str2);
                file.delete();
            }
            promise.a((Object) true);
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void copyFile(String str, String str2, ReadableMap readableMap, Promise promise) {
        try {
            copyFile(str, str2);
            promise.a((Object) null);
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    private void copyFile(String str, String str2) throws IOException, IORejectionException {
        InputStream inputStream = getInputStream(str);
        OutputStream outputStream = getOutputStream(str2, false);
        byte[] bArr = new byte[1024];
        while (true) {
            int read = inputStream.read(bArr);
            if (read > 0) {
                outputStream.write(bArr, 0, read);
            } else {
                inputStream.close();
                outputStream.close();
                return;
            }
        }
    }

    @ReactMethod
    public void readDir(String str, Promise promise) {
        try {
            File file = new File(str);
            if (file.exists()) {
                File[] listFiles = file.listFiles();
                WritableArray a2 = Arguments.a();
                for (File file2 : listFiles) {
                    WritableMap b = Arguments.b();
                    b.putDouble("mtime", ((double) file2.lastModified()) / 1000.0d);
                    b.putString("name", file2.getName());
                    b.putString("path", file2.getAbsolutePath());
                    b.putInt("size", (int) file2.length());
                    b.putInt("type", file2.isDirectory() ? 1 : 0);
                    a2.a(b);
                }
                promise.a(a2);
                return;
            }
            throw new Exception("Folder does not exist");
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:29:0x005d A[SYNTHETIC] */
    @ReactMethod
    public void readDirAssets(String str, Promise promise) {
        int i;
        IOException e;
        try {
            AssetManager assets = getReactApplicationContext().getAssets();
            String[] list = assets.list(str);
            WritableArray a2 = Arguments.a();
            for (String str2 : list) {
                WritableMap b = Arguments.b();
                b.putString("name", str2);
                int i2 = 1;
                if (!str.isEmpty()) {
                    str2 = String.format("%s/%s", str, str2);
                }
                b.putString("path", str2);
                try {
                    AssetFileDescriptor openFd = assets.openFd(str2);
                    if (openFd != null) {
                        i = (int) openFd.getLength();
                        try {
                            openFd.close();
                        } catch (IOException e2) {
                            e = e2;
                            if (e.getMessage().indexOf("compressed") == -1) {
                                b.putInt("size", i);
                                b.putInt("type", i2);
                                a2.a(b);
                            }
                            i2 = 0;
                            b.putInt("size", i);
                            b.putInt("type", i2);
                            a2.a(b);
                        }
                        i2 = 0;
                        b.putInt("size", i);
                        b.putInt("type", i2);
                        a2.a(b);
                    } else {
                        i = 0;
                        b.putInt("size", i);
                        b.putInt("type", i2);
                        a2.a(b);
                    }
                } catch (IOException e3) {
                    e = e3;
                    i = 0;
                    if (e.getMessage().indexOf("compressed") == -1) {
                    }
                    i2 = 0;
                    b.putInt("size", i);
                    b.putInt("type", i2);
                    a2.a(b);
                }
            }
            promise.a(a2);
        } catch (IOException e4) {
            reject(promise, str, e4);
        }
    }

    @ReactMethod
    public void copyFileAssets(String str, String str2, Promise promise) {
        try {
            copyInputStream(getReactApplicationContext().getAssets().open(str), str, str2, promise);
        } catch (IOException unused) {
            reject(promise, str, new Exception(String.format("Asset '%s' could not be opened", str)));
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:29:0x003d  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0043 A[SYNTHETIC, Splitter:B:31:0x0043] */
    /* JADX WARNING: Removed duplicated region for block: B:41:? A[RETURN, SYNTHETIC] */
    @ReactMethod
    public void existsAssets(String str, Promise promise) {
        Throwable th;
        try {
            AssetManager assets = getReactApplicationContext().getAssets();
            try {
                String[] list = assets.list(str);
                if (list != null && list.length > 0) {
                    promise.a((Object) true);
                    return;
                }
            } catch (Exception unused) {
            }
            InputStream inputStream = null;
            try {
                InputStream open = assets.open(str);
                try {
                    promise.a((Object) true);
                    if (open != null) {
                        try {
                            open.close();
                        } catch (Exception unused2) {
                        }
                    }
                } catch (Exception unused3) {
                    inputStream = open;
                    try {
                        promise.a((Object) false);
                        if (inputStream == null) {
                            inputStream.close();
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        if (inputStream != null) {
                            try {
                                inputStream.close();
                            } catch (Exception unused4) {
                            }
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    inputStream = open;
                    if (inputStream != null) {
                    }
                    throw th;
                }
            } catch (Exception unused5) {
                promise.a((Object) false);
                if (inputStream == null) {
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x004f A[SYNTHETIC, Splitter:B:26:0x004f] */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x005a A[SYNTHETIC, Splitter:B:32:0x005a] */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0061 A[SYNTHETIC, Splitter:B:36:0x0061] */
    /* JADX WARNING: Removed duplicated region for block: B:43:? A[RETURN, SYNTHETIC] */
    private void copyInputStream(InputStream inputStream, String str, String str2, Promise promise) {
        Throwable th;
        OutputStream outputStream;
        Exception e;
        try {
            outputStream = getOutputStream(str2, false);
            try {
                byte[] bArr = new byte[10240];
                while (true) {
                    int read = inputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    outputStream.write(bArr, 0, read);
                }
                promise.a((Object) null);
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (IOException unused) {
                    }
                }
                if (outputStream == null) {
                    return;
                }
            } catch (Exception e2) {
                e = e2;
                try {
                    reject(promise, str, new Exception(String.format("Failed to copy '%s' to %s (%s)", str, str2, e.getLocalizedMessage())));
                    if (inputStream != null) {
                    }
                    if (outputStream == null) {
                    }
                    outputStream.close();
                } catch (Throwable th2) {
                    th = th2;
                    if (inputStream != null) {
                        try {
                            inputStream.close();
                        } catch (IOException unused2) {
                        }
                    }
                    if (outputStream != null) {
                        try {
                            outputStream.close();
                        } catch (IOException unused3) {
                        }
                    }
                    throw th;
                }
            }
        } catch (Exception e3) {
            outputStream = null;
            e = e3;
            reject(promise, str, new Exception(String.format("Failed to copy '%s' to %s (%s)", str, str2, e.getLocalizedMessage())));
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException unused4) {
                }
            }
            if (outputStream == null) {
                return;
            }
            outputStream.close();
        } catch (Throwable th3) {
            th = th3;
            outputStream = null;
            if (inputStream != null) {
            }
            if (outputStream != null) {
            }
            throw th;
        }
        try {
            outputStream.close();
        } catch (IOException unused5) {
        }
    }

    @ReactMethod
    public void setReadable(String str, Boolean bool, Boolean bool2, Promise promise) {
        try {
            File file = new File(str);
            if (file.exists()) {
                file.setReadable(bool.booleanValue(), bool2.booleanValue());
                promise.a((Object) true);
                return;
            }
            throw new Exception("File does not exist");
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void stat(String str, Promise promise) {
        try {
            String originalFilepath = getOriginalFilepath(str);
            File file = new File(originalFilepath);
            if (file.exists()) {
                WritableMap b = Arguments.b();
                b.putInt("ctime", (int) (file.lastModified() / 1000));
                b.putInt("mtime", (int) (file.lastModified() / 1000));
                b.putInt("size", (int) file.length());
                b.putInt("type", file.isDirectory() ? 1 : 0);
                b.putString("originalFilepath", originalFilepath);
                promise.a(b);
                return;
            }
            throw new Exception("File does not exist");
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void unlink(String str, Promise promise) {
        try {
            File file = new File(str);
            if (file.exists()) {
                DeleteRecursive(file);
                promise.a((Object) null);
                return;
            }
            throw new Exception("File does not exist");
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    private void DeleteRecursive(File file) {
        if (file.isDirectory()) {
            for (File file2 : file.listFiles()) {
                DeleteRecursive(file2);
            }
        }
        file.delete();
    }

    @ReactMethod
    public void mkdir(String str, ReadableMap readableMap, Promise promise) {
        try {
            File file = new File(str);
            file.mkdirs();
            if (file.exists()) {
                promise.a((Object) null);
                return;
            }
            throw new Exception("Directory could not be created");
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendEvent(ReactContext reactContext2, String str, @Nullable WritableMap writableMap) {
        ((RCTNativeAppEventEmitter) reactContext2.a(RCTNativeAppEventEmitter.class)).emit(str, writableMap);
    }

    @ReactMethod
    public void downloadFile(final ReadableMap readableMap, final Promise promise) {
        try {
            File file = new File(readableMap.f("toFile"));
            URL url = new URL(readableMap.f("fromUrl"));
            final int e = readableMap.e("jobId");
            ReadableMap g = readableMap.g("headers");
            int e2 = readableMap.e("progressDivider");
            int e3 = readableMap.e("readTimeout");
            int e4 = readableMap.e("connectionTimeout");
            DownloadParams downloadParams = new DownloadParams();
            downloadParams.f2809a = url;
            downloadParams.b = file;
            downloadParams.c = g;
            downloadParams.d = (float) e2;
            downloadParams.e = e3;
            downloadParams.f = e4;
            downloadParams.g = new DownloadParams.OnTaskCompleted() {
                /* class com.rnfs.RNFSManager.AnonymousClass1 */

                @Override // com.rnfs.DownloadParams.OnTaskCompleted
                public void a(DownloadResult downloadResult) {
                    if (downloadResult.c == null) {
                        WritableMap b2 = Arguments.b();
                        b2.putInt("jobId", e);
                        b2.putInt("statusCode", downloadResult.f2810a);
                        b2.putInt("bytesWritten", downloadResult.b);
                        promise.a(b2);
                        return;
                    }
                    RNFSManager.this.reject(promise, readableMap.f("toFile"), downloadResult.c);
                }
            };
            downloadParams.h = new DownloadParams.OnDownloadBegin() {
                /* class com.rnfs.RNFSManager.AnonymousClass2 */

                @Override // com.rnfs.DownloadParams.OnDownloadBegin
                public void a(int i, int i2, Map<String, String> map) {
                    WritableMap b2 = Arguments.b();
                    for (Map.Entry<String, String> entry : map.entrySet()) {
                        b2.putString(entry.getKey(), entry.getValue());
                    }
                    WritableMap b3 = Arguments.b();
                    b3.putInt("jobId", e);
                    b3.putInt("statusCode", i);
                    b3.putInt("contentLength", i2);
                    b3.a("headers", b2);
                    RNFSManager rNFSManager = RNFSManager.this;
                    ReactApplicationContext reactApplicationContext = RNFSManager.this.getReactApplicationContext();
                    rNFSManager.sendEvent(reactApplicationContext, "DownloadBegin-" + e, b3);
                }
            };
            downloadParams.i = new DownloadParams.OnDownloadProgress() {
                /* class com.rnfs.RNFSManager.AnonymousClass3 */

                @Override // com.rnfs.DownloadParams.OnDownloadProgress
                public void a(int i, int i2) {
                    WritableMap b2 = Arguments.b();
                    b2.putInt("jobId", e);
                    b2.putInt("contentLength", i);
                    b2.putInt("bytesWritten", i2);
                    RNFSManager rNFSManager = RNFSManager.this;
                    ReactApplicationContext reactApplicationContext = RNFSManager.this.getReactApplicationContext();
                    rNFSManager.sendEvent(reactApplicationContext, "DownloadProgress-" + e, b2);
                }
            };
            Downloader downloader = new Downloader();
            downloader.execute(downloadParams);
            this.downloaders.put(e, downloader);
        } catch (Exception e5) {
            e5.printStackTrace();
            reject(promise, readableMap.f("toFile"), e5);
        }
    }

    @ReactMethod
    public void stopDownload(int i) {
        Downloader downloader = this.downloaders.get(i);
        if (downloader != null) {
            downloader.a();
        }
    }

    @ReactMethod
    public void uploadFiles(final ReadableMap readableMap, final Promise promise) {
        try {
            ReadableArray k = readableMap.k("files");
            URL url = new URL(readableMap.f("toUrl"));
            final int e = readableMap.e("jobId");
            ReadableMap g = readableMap.g("headers");
            ReadableMap g2 = readableMap.g("fields");
            String f = readableMap.f("method");
            ArrayList<ReadableMap> arrayList = new ArrayList<>();
            UploadParams uploadParams = new UploadParams();
            for (int i = 0; i < k.a(); i++) {
                arrayList.add(k.i(i));
            }
            uploadParams.f2820a = url;
            uploadParams.b = arrayList;
            uploadParams.c = g;
            uploadParams.e = f;
            uploadParams.d = g2;
            uploadParams.f = new UploadParams.onUploadComplete() {
                /* class com.rnfs.RNFSManager.AnonymousClass4 */

                @Override // com.rnfs.UploadParams.onUploadComplete
                public void a(UploadResult uploadResult) {
                    if (uploadResult.c == null) {
                        WritableMap b2 = Arguments.b();
                        b2.putInt("jobId", e);
                        b2.putInt("statusCode", uploadResult.f2821a);
                        b2.a("headers", uploadResult.b);
                        b2.putString("body", uploadResult.d);
                        promise.a(b2);
                        return;
                    }
                    RNFSManager.this.reject(promise, readableMap.f("toUrl"), uploadResult.c);
                }
            };
            uploadParams.h = new UploadParams.onUploadBegin() {
                /* class com.rnfs.RNFSManager.AnonymousClass5 */

                @Override // com.rnfs.UploadParams.onUploadBegin
                public void a() {
                    WritableMap b2 = Arguments.b();
                    b2.putInt("jobId", e);
                    RNFSManager rNFSManager = RNFSManager.this;
                    ReactApplicationContext reactApplicationContext = RNFSManager.this.getReactApplicationContext();
                    rNFSManager.sendEvent(reactApplicationContext, "UploadBegin-" + e, b2);
                }
            };
            uploadParams.g = new UploadParams.onUploadProgress() {
                /* class com.rnfs.RNFSManager.AnonymousClass6 */

                @Override // com.rnfs.UploadParams.onUploadProgress
                public void a(int i, int i2, int i3) {
                    WritableMap b2 = Arguments.b();
                    b2.putInt("jobId", e);
                    b2.putInt("FileID", i);
                    b2.putInt("totalBytesExpectedToSend", i2);
                    b2.putInt("totalBytesSent", i3);
                    RNFSManager rNFSManager = RNFSManager.this;
                    ReactApplicationContext reactApplicationContext = RNFSManager.this.getReactApplicationContext();
                    rNFSManager.sendEvent(reactApplicationContext, "UploadProgress-" + e, b2);
                }
            };
            Uploader uploader = new Uploader();
            uploader.execute(uploadParams);
            this.uploaders.put(e, uploader);
        } catch (Exception e2) {
            e2.printStackTrace();
            reject(promise, readableMap.f("toUrl"), e2);
        }
    }

    @ReactMethod
    public void stopUpload(int i) {
        Uploader uploader = this.uploaders.get(i);
        if (uploader != null) {
            uploader.a();
        }
    }

    @ReactMethod
    public void getFSInfo(Promise promise) {
        long j;
        long j2;
        StatFs statFs = new StatFs(Environment.getDataDirectory().getPath());
        if (Build.VERSION.SDK_INT >= 18) {
            j = statFs.getTotalBytes();
            j2 = statFs.getFreeBytes();
        } else {
            long blockSize = (long) statFs.getBlockSize();
            j2 = ((long) statFs.getAvailableBlocks()) * blockSize;
            j = ((long) statFs.getBlockCount()) * blockSize;
        }
        WritableMap b = Arguments.b();
        b.putDouble("totalSpace", (double) j);
        b.putDouble("freeSpace", (double) j2);
        promise.a(b);
    }

    @ReactMethod
    public void touch(String str, double d, double d2, Promise promise) {
        try {
            promise.a(Boolean.valueOf(new File(str).setLastModified((long) d)));
        } catch (Exception e) {
            e.printStackTrace();
            reject(promise, str, e);
        }
    }

    @ReactMethod
    public void getAllExternalFilesDirs(Promise promise) {
        File[] externalFilesDirs = getReactApplicationContext().getExternalFilesDirs(null);
        WritableArray a2 = Arguments.a();
        for (File file : externalFilesDirs) {
            a2.pushString(file.getAbsolutePath());
        }
        promise.a(a2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void reject(Promise promise, String str, Exception exc) {
        if (exc instanceof FileNotFoundException) {
            rejectFileNotFound(promise, str);
        } else if (exc instanceof IORejectionException) {
            IORejectionException iORejectionException = (IORejectionException) exc;
            promise.a(iORejectionException.a(), iORejectionException.getMessage());
        } else {
            promise.a((String) null, exc.getMessage());
        }
    }

    private void rejectFileNotFound(Promise promise, String str) {
        promise.a("ENOENT", "ENOENT: no such file or directory, open '" + str + "'");
    }

    private void rejectFileIsDirectory(Promise promise) {
        promise.a("EISDIR", "EISDIR: illegal operation on a directory, read");
    }

    @Override // com.facebook.react.bridge.BaseJavaModule
    public Map<String, Object> getConstants() {
        HashMap hashMap = new HashMap();
        hashMap.put(RNFSDocumentDirectory, 0);
        hashMap.put(RNFSDocumentDirectoryPath, getReactApplicationContext().getFilesDir().getAbsolutePath());
        hashMap.put(RNFSTemporaryDirectoryPath, getReactApplicationContext().getCacheDir().getAbsolutePath());
        hashMap.put(RNFSPicturesDirectoryPath, Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES).getAbsolutePath());
        hashMap.put(RNFSCachesDirectoryPath, getReactApplicationContext().getCacheDir().getAbsolutePath());
        hashMap.put(RNFSFileTypeRegular, 0);
        hashMap.put(RNFSFileTypeDirectory, 1);
        File externalStorageDirectory = Environment.getExternalStorageDirectory();
        if (externalStorageDirectory != null) {
            hashMap.put(RNFSExternalStorageDirectoryPath, externalStorageDirectory.getAbsolutePath());
        } else {
            hashMap.put(RNFSExternalStorageDirectoryPath, null);
        }
        File externalFilesDir = getReactApplicationContext().getExternalFilesDir(null);
        if (externalFilesDir != null) {
            hashMap.put(RNFSExternalDirectoryPath, externalFilesDir.getAbsolutePath());
        } else {
            hashMap.put(RNFSExternalDirectoryPath, null);
        }
        File externalCacheDir = getReactApplicationContext().getExternalCacheDir();
        if (externalCacheDir != null) {
            hashMap.put(RNFSExternalCachesDirectoryPath, externalCacheDir.getAbsolutePath());
        } else {
            hashMap.put(RNFSExternalCachesDirectoryPath, null);
        }
        return hashMap;
    }
}
